%==========================================================================
% SALMON.m
%==========================================================================
set(0,'DefaultAxesFontName','Times New Roman','DefaultAxesFontSize',14);

global I drain_order LU omega A mu l W Q0 Ql C00 Cl0 Cbar0 eta mass0 mass q;

InputFile = [pwd '\SALMONsupplemental.xls'];

SALMON_header;

SALMON_set_parameters;

SALMON_raw_graph;

SALMON_wild_graph;

SALMON_pva_graph; 

pause;

if exist('PVAf');
    fprintf('\nProd(size(PVAf)) = %-.0f\n', prod(size(PVAf)));
    answer = input('Create PVA meta-model? [0] = no, [1] = yes: ');
    if answer == 1; 
        SALMON_pva_function;
    end; 
else;
    SALMON_pva_function;
end;   

%pause;

% With parameters calibrated, select watersheds for protection using
% the following algorithms:
% 1. Naive cost criterion: choose watersheds in increasing order of costs
% 2. Naive biology criterion: choose watersheds in decreasing order of
%    the initial ecological benefits
% 3. Naive benefit-cost criterion: choose watersheds in decreasing
%    order of their initial benefit-cost ratios
% 4. Updated benefit-cost criterion: choose watersheds in decreasing order 
%    of their benefit-cost ratios, updating benefits at each iteration
% 5. Optimal: (for a feasibly small problem) check all possible 
%    combinations of watersheds

for zz = 1:1; break;
fprintf('\nWhich objective do you want to maximize?\n');
fprintf('   [1] = probability that all 3 stocks survive,\n'); 
objective = ...
  input('   [2] = probability that at least one stock survives: ');
end;
objective = 1;

% Calculate initial extinction probabilities, with no watersheds protected:
x  = zeros(I,1);
beta_temp = beta;
p100M_baseline = SALMON_ext_probs_fast(PVAf,beta_temp,1);

%------------------------------------------------------------------------------------------------------------
% 0. Random
%------------------------------------------------------------------------------------------------------------
for zz = 1:1; %break;

REPS = 100;
COST_0  = zeros(I,REPS);
p100M_0 = zeros(I,REPS);
for rep = 1:REPS;
    SALMON_header; fprintf('Selecting watersheds randomly:\n');
    fprintf('  Working on rep %3.0f of %3.0f\n',rep,REPS); pause(0.1);
    rand('state',500+rep);
    [random_sorted,random_order] = sort(rand(I,1));
    x = zeros(I,1);
    beta_temp = beta;
    index = 0;
    for ii = random_order';
       index = index + 1;
       x(ii) = 1;
       xtemp = x;
       [C0,Cl,Cbar] = SALMON_concentrations(x);
       for m = 1:M;
           wsheds = find(W(:,m+6)==1);
           beta_temp(m) = ...
               b(m)*sum(h(wsheds).*exp(-rho(m)*Cbar(wsheds).*(1-x(wsheds))));
       end;
       p100M_0(index,rep) = SALMON_ext_probs_fast(PVAf,beta_temp,1);
       if ii == random_order(1); 
           COST_0(1,rep) = cost(ii);
       else; 
           COST_0(index,rep) = COST_0(index-1,rep) + cost(ii); 
       end;
    end;
end;

SLICES = 200;
p100M_0_interp = zeros(SLICES,REPS);
for rep = 1:REPS;
    slice = 0;
    cost_interp_range = [sum(cost)/SLICES:sum(cost)/SLICES:sum(cost)]';
    for cost_slice = cost_interp_range';
        slice = slice + 1;
        temp = find(COST_0(:,rep)+.1 >= cost_slice);
        if length(temp)==I;
            c1 = 0; c2 = COST_0(1,rep); 
            p1 = p100M_baseline; p2 = p100M_0(1);
        else length(temp) > 1;
            c1 = COST_0(temp(1)-1,rep);  c2 = COST_0(temp(1),rep);
            p1 = p100M_0(temp(1)-1,rep); p2 = p100M_0(temp(1),rep);
        end;
        p100M_0_interp(slice,rep) = p1 + (cost_slice-c1)/(c2-c1)*(p2-p1);
    end;
end;
p100M_0_mean = mean(p100M_0_interp')';
for slice = 1:SLICES;
    temp = sort(p100M_0_interp(slice,:)');
    p100M_0_lo(slice) = temp(min(1,fix(REPS*.025)));
    p100M_0_up(slice) = temp(fix(REPS*.975));
end;
p100M_0_lo = p100M_0_lo';
p100M_0_up = p100M_0_up';
%plot(p100M_0_lo,'k--'); hold on;
%plot(p100M_0_mean,'k');
%plot(p100M_0_up,'k--'); hold off;

SALMON_save; %pause;

end;


for zz = 1:1; %break;
%------------------------------------------------------------------------------------------------------------
% 1. Naive cost criterion: choose watersheds in increasing order of cost 
%------------------------------------------------------------------------------------------------------------
A    = W(:,6);
[trash,order_1] = sort(cost);
p100M_1 = zeros(I,1);  
COST_1  = zeros(I,1);  
x       = zeros(I,1);  
index   = 0;
for ii = order_1'; 
    index = index + 1;
    x(ii) = 1;
    xtemp = x;
    [C0,Cl,Cbar] = SALMON_concentrations(x);
    for m = 1:M;
        wsheds = find(W(:,m+6)==1);
        beta_temp(m) = ...
            b(m)*sum(h(wsheds).*exp(-rho(m)*Cbar(wsheds).*(1-x(wsheds))));
    end;
    p100M_1(index) = SALMON_ext_probs_fast(PVAf,beta_temp,1);
    if ii == order_1(1); COST_1(1) = cost(ii);
    else; COST_1(index) = COST_1(index-1) + cost(ii); end;
    
    SALMON_header;
    fprintf('Selecting watersheds using costs only:\n');
    fprintf('    Working on %-.0f of %-.0f\n',index,I);
    for m = 1:M;
    fprintf('    beta_temp(%-.0f) = %-.1f\n',m,beta_temp(m));
    end;
    fprintf('    p100M_1(%-.0f)   = %-.6f\n',index,p100M_1(index));
    pause(0.01);
end;

[COST_1,temp]=sort(COST_1); p100M_1 = p100M_1(temp);

SALMON_save;

end;


for zz = 1:1; %break; 
%------------------------------------------------------------------------------------------------------------
% 2. Naive biology criterion: choose watersheds in decreasing order of length of spawning-rearing habitat
%------------------------------------------------------------------------------------------------------------
p100M_2  = zeros(I,1);   
COST_2   = zeros(I,1);   
x        = zeros(I,1); 
deltap_0 = zeros(I,1);
BonC_0   = zeros(I,1);
SALMON_header;
fprintf('Calculating deltap_0:\n'); 
x = zeros(I,1); xtemp = x; [C0,Cl,Cbar] = SALMON_concentrations(x);
for m = 1:M;
    wsheds = find(W(:,m+6)==1);
    beta_temp(m) = b(m)*sum(h(wsheds).*exp(-rho(m)*Cbar(wsheds).*(1-x(wsheds))));
end;
beta0 = beta_temp;
Cbar0 = Cbar;
mass0 = mass;
C00   = C0;
Cl0   = Cl;
p100M_0 = SALMON_ext_probs_fast(PVAf,beta_temp,1);
for m = 1:M;
    fprintf('    beta_temp(%-.0f) = %-.1f\n',m,beta_temp(m));
end;
fprintf('        p100M_0 = %10.5f\n',p100M_0); 
pause(0.01);
for ii = 1:I;
    x = zeros(I,1); 
    x(ii) = 1;
    xtemp = x;
    [C0,Cl,Cbar] = SALMON_concentrations(x);
    for m = 1:M;
        wsheds = find(W(:,m+6)==1);
        beta_temp(m) = b(m)*sum(h(wsheds).*exp(-rho(m)*Cbar(wsheds).*(1-x(wsheds))));
    end;
    p100 = SALMON_ext_probs_fast(PVAf,beta_temp,1);
    deltap_0(ii) = p100-p100M_0;
    BonC_0(ii)   = deltap_0(ii)/cost(ii);
    for m = 1:M;
    fprintf('    beta_temp(%-.0f) = %-.1f\n',m,beta_temp(m));
    end;
    fprintf('        deltap_0(%-.0f) = %10.5f\n',ii,deltap_0(ii)); 
    pause(0.01);
end;
[sorted_deltap_0,order_2] = sort(-h);
SALMON_save;

x = zeros(I,1);
index = 0;
for ii = order_2'; 
    index = index + 1;
    x(ii) = 1;
    xtemp = x;
    [C0,Cl,Cbar] = SALMON_concentrations(x);
    for m = 1:M;
        wsheds = find(W(:,m+6)==1);
        beta_temp(m) = b(m)*sum(h(wsheds).*exp(-rho(m)*Cbar(wsheds).*(1-x(wsheds))));
    end;
    p100M_2(index) = SALMON_ext_probs_fast(PVAf,beta_temp,1);
    if ii == order_2(1); 
        COST_2(1) = cost(ii);
    else; 
        COST_2(index) = COST_2(index-1) + cost(ii); 
    end;
    
    SALMON_header;
    fprintf('Selecting watersheds using initial biological benefits only:\n');
    fprintf('    Working on %-.0f of %-.0f\n',index,I);
    fprintf('    p100M_2(%-.0f) = %-.4f\n',index,p100M_2(index));
    pause(0.01);
end;
[COST_2,temp] = sort(COST_2); p100M_2 = p100M_2(temp);

SALMON_save;

end;

for zz = 1:1; break;
% Regress deltap_0 on watershed attributes:
y = deltap_0;
x = [ones(I,1) A l h ldown ...
    sum(LU(:,[3:5 19])')' ...   urban
    sum(LU(:,9:11)')' ...       forest
    sum(LU(:,[13 15:18])')']; % ag
y = y./std(y);
for i = 1:I;
    x(i,2:end) = x(i,2:end)./std(x(:,2:end));
end;
betahat = inv(x'*x)*x'*y;
yhat    = x*betahat;
ESS     = sum((y-yhat).^2);
TSS     = sum((y-mean(y)).^2);
sig2hat = ESS/(I-8);
se      = sqrt( sig2hat./diag(inv(x'*x)) );
R2      = (TSS-ESS)/TSS;
end;


for zz = 1:1; %break;
%------------------------------------------------------------------------------------------------------------
% 3. Naive benefit-cost criterion: choose watersheds in decreasing order of spawning habitat/cost ratios
%------------------------------------------------------------------------------------------------------------
[trash,order_3] = sort(-h./cost);
p100M_3 = zeros(I,1); 
COST_3 = zeros(I,1);   
x      = zeros(I,1);
index  = 0;
for ii = order_3'; 
    index = index + 1;
    x(ii) = 1;
    xtemp = x;
    [C0,Cl,Cbar] = SALMON_concentrations(x);
    for m = 1:M;
        wsheds = find(W(:,m+6)==1);
        beta_temp(m) = b(m)*sum(h(wsheds).*exp(-rho(m)*Cbar(wsheds).*(1-x(wsheds))));
    end;
    p100M_3(index) = SALMON_ext_probs_fast(PVAf,beta_temp,1);
    if ii == order_3(1); COST_3(1) = cost(ii);
    else; COST_3(index) = COST_3(index-1) + cost(ii); end;
    SALMON_header;
    fprintf('Selecting watersheds using spawning habitat-cost ratios:\n');
    fprintf('    Working on %-.0f of %-.0f\n',index,I);
    fprintf('    p100M_3(%-.0f) = %-.4f\n',index,p100M_3(index));
    pause(0.01);
end;
[COST_3,temp]=sort(COST_3);
p100M_3 = p100M_3(temp);
SALMON_save;
end;


for zz = 1:1; %break;
%------------------------------------------------------------------------------------------------------------
% 4. Initial benefit-cost criterion: choose watersheds in increasing order of initial benefit-cost ratios
%------------------------------------------------------------------------------------------------------------
[trash,order_4] = sort(-deltap_0./cost);
p100M_4 = zeros(I,1); 
COST_4 = zeros(I,1);  
x = zeros(I,1);
index  = 0;
for ii = order_4'; 
    index = index + 1;
    x(ii) = 1;
    xtemp = x;
    [C0,Cl,Cbar] = SALMON_concentrations(x);
    for m = 1:M;
        wsheds = find(W(:,m+6)==1);
        beta_temp(m) = b(m)*sum(h(wsheds).*exp(-rho(m)*Cbar(wsheds).*(1-x(wsheds))));
    end;
    p100M_4(index) = SALMON_ext_probs_fast(PVAf,beta_temp,1);
    if ii == order_4(1); COST_4(1) = cost(ii);
    else; COST_4(index) = COST_4(index-1) + cost(ii); end;
    SALMON_header;
    fprintf('Selecting watersheds using initial benefit-cost ratios:\n');
    fprintf('    Working on %-.0f of %-.0f\n',index,I);
    fprintf('    p100M_4(%-.0f) = %-.4f\n',index,p100M_4(index));
    pause(0.01);
end;
SALMON_save;
end;


for zz = 1:1; %break;
%------------------------------------------------------------------------------------------------------------
% 5. Updated benefit-cost criterion: choose watersheds in decreasing order of b-c ratios, 
%    updating benefits at each iteration
%------------------------------------------------------------------------------------------------------------
order_5 = zeros(I,1);
p100M_5 = zeros(I,1); 
COST_5  = zeros(I,1);  
x       = zeros(I,1);
x_5     = zeros(I,1); 

% cost=ones(size(cost))+rand(size(cost))*0.00001;

for ii = 1:I; 
    SALMON_header;
    fprintf('Selecting watersheds using updated benefit-cost ratios:\n');
    fprintf('    Major iteration %-.0f of %-.0f\n',ii,I);
    BonC = zeros(I,1);
    for iii = 1:I;
        if x_5(iii) == 0;
        x = x_5; 
        x(iii) = 1;
        xtemp = x; 
        [C0,Cl,Cbar] = SALMON_concentrations(x);
        for m = 1:M;
            wsheds = find(W(:,m+6)==1);
            beta_temp(m) = b(m)*sum(h(wsheds).*exp(-rho(m)*Cbar(wsheds).*(1-x(wsheds))));
        end;
        p100M_temp(iii) = SALMON_ext_probs_fast(PVAf,beta_temp,1);
        if ii == 1; BonC(iii) = (p100M_temp(iii)-p100M_0)/cost(iii);
        else;       BonC(iii) = (p100M_temp(iii)-p100M_5(ii-1))/cost(iii);   end;
        fprintf('        Protecting wshed %-.0f would give beta1 = %-.2f & p100M = %-.6f & B/C = %-.4f\n',...
            iii,beta_temp(1),p100M_temp(iii),BonC(iii)*mean(cost)); %pause;
        end;
    end;
    if sum(BonC) > 0;
        order_5(ii) = find(BonC==max(BonC));
    elseif sum(BonC) <= 0;
        temp = BonC_0.*(1-x_5);
        if sum(temp) > 0; order_5(ii) = find(temp==max(temp)); else;
            order_5(ii) = find(cost+x_5*max(cost)==min(cost+x_5*max(cost)));
        end;
    end;
    if x_5(order_5(ii)) == 1; fprintf('Warning: Watershed %-.0f already selected!\n',ii); pause; end;
    x_5(order_5(ii)) = 1; p100M_5(ii) = p100M_temp(order_5(ii)); 
    if ii == 1; COST_5(1) = cost(order_5(1));
    else; COST_5(ii) = COST_5(ii-1) + cost(order_5(ii)); end;  
    fprintf('        Watershed %-.0f selected: p100M_5(%-.0f) = %-.6f; COST_5(%-.0f) = %-.0f\n',...
        order_5(ii),ii,p100M_5(ii),ii,COST_5(ii));
end;

COST_5  = nonzeros(COST_5);  [COST_5,temp] = sort(COST_5);
p100M_5 = nonzeros(p100M_5); p100M_5 = p100M_5(temp);

SALMON_save;

end;
  
SALMON_graph;   

stock_1 = zeros(I,1);
stock_2 = zeros(I,1);
stock_3 = zeros(I,1);
stock_4 = zeros(I,1);
stock_5 = zeros(I,1);

for i = 1:I; %break;
    
    if W(order_1(i),7)==1;     stock_1(i) = 1;
    elseif W(order_1(i),8)==1; stock_1(i) = 2;
    elseif W(order_1(i),9)==1; stock_1(i) = 3;
    end;    
    
    if W(order_2(i),7)==1;     stock_2(i) = 1;
    elseif W(order_2(i),8)==1; stock_2(i) = 2;
    elseif W(order_2(i),9)==1; stock_2(i) = 3;
    end;
    
    if W(order_3(i),7)==1;     stock_3(i) = 1;
    elseif W(order_3(i),8)==1; stock_3(i) = 2;
    elseif W(order_3(i),9)==1; stock_3(i) = 3;
    end;    
    
    if W(order_4(i),7)==1;     stock_4(i) = 1;
    elseif W(order_4(i),8)==1; stock_4(i) = 2;
    elseif W(order_4(i),9)==1; stock_4(i) = 3;
    end;
    
    if W(order_5(i),7)==1;     stock_5(i) = 1;
    elseif W(order_5(i),8)==1; stock_5(i) = 2;
    elseif W(order_5(i),9)==1; stock_5(i) = 3;
    end;  
    
end;

ranking_1 = zeros(I,1);
ranking_2 = zeros(I,1);
ranking_3 = zeros(I,1);
ranking_4 = zeros(I,1);
ranking_5 = zeros(I,1);
for i = 1:I;
    ranking_1(i) = find(order_1==i); 
    ranking_2(i) = find(order_2==i); 
    ranking_3(i) = find(order_3==i); 
    ranking_4(i) = find(order_4==i); 
    ranking_5(i) = find(order_5==i); 
end;

num2str([order_1 stock_1 COST_1 p100M_1 ...
         order_2 stock_2 COST_2 p100M_2 ...
         order_3 stock_3 COST_3 p100M_3 ...
         order_4 stock_4 COST_4 p100M_4 ...
         order_5 stock_5 COST_5 p100M_5])
     
fprintf('Watershed rankings using all 5 prioritization approaches:\n');
num2str([ranking_1 ranking_2 ranking_3 ranking_4 ranking_5])

p_interp1 = interp1(COST_1/COST_1(end),(p100M_1-p100M_baseline)/(p100M_1(end)-p100M_baseline),[0:.01:1]');
p_interp2 = interp1(COST_2/COST_2(end),(p100M_2-p100M_baseline)/(p100M_2(end)-p100M_baseline),[0:.01:1]');
p_interp3 = interp1(COST_3/COST_3(end),(p100M_3-p100M_baseline)/(p100M_3(end)-p100M_baseline),[0:.01:1]');
p_interp4 = interp1(COST_4/COST_4(end),(p100M_4-p100M_baseline)/(p100M_4(end)-p100M_baseline),[0:.01:1]');
p_interp5 = interp1(COST_5/COST_5(end),(p100M_5-p100M_baseline)/(p100M_5(end)-p100M_baseline),[0:.01:1]');

fprintf('Spending 10 percent of total cost achieves the following percent\n');
fprintf('of maximum possible increase in persistence:\n');
fprintf('costs         %5.1f\n',p_interp1(11)*100);
fprintf('habitat       %5.1f\n',p_interp2(11)*100);
fprintf('habitat/cost  %5.1f\n',p_interp3(11)*100);
fprintf('initial b/c   %5.1f\n',p_interp4(11)*100);
fprintf('updated b/c   %5.1f\n',p_interp5(11)*100);

SALMON_save;