%==========================================================================
% SALMON_BH_graphs.m
%==========================================================================
set(0,'DefaultAxesFontName','Times New Roman','DefaultAxesFontSize',14);

parmsM = xlsread(InputFile,'Methow_boot_revised');
parmsE = xlsread(InputFile,'Entiat_boot_revised');
parmsW = xlsread(InputFile,'Wenatchee_boot_revised');

parmsM = parmsM(:,1:3);
parmsE = parmsE(:,1:3);
parmsW = parmsW(:,1:3);

factor = 1;

MC = 50000;

% Methow
SMmax = 10000;
SMrange = [1:(SMmax-1)/99:SMmax]';

RM_p = zeros(MC,100);
RMe_ = zeros(MC,100);
RMep = zeros(MC,100);

alphaM_ml = exp(0.5012);  %alphaM_ml = mean(parmsM(:,1));
betaM_ml  = exp(7.4832);  %betaM_ml  = mean(parmsM(:,2));

for mc = 1:MC;
    if fix(mc/1000)-mc/1000==0; clc; fprintf('Working on %-.0f of %-.0f\n',mc,MC); pause(0.01); end;
    draw  = fix(rand*length(parmsM))+1;
    alpha = parmsM(draw,1);
    beta  = parmsM(draw,2);
    sigma = parmsM(draw,3);
    i = 0;
    for S = SMrange'; i = i + 1;
        RM_p(mc,i) = alpha*S/(1+S/beta);
        epsilon    = randn(1,1)*sigma;
        RMe_(mc,i) = alphaM_ml*S/(1+S/betaM_ml)*exp(epsilon*factor);
        RMep(mc,i) = alpha*S/(1+S/beta)*exp(epsilon);
    end;
end;
RM_p    = sort(RM_p);
RM_p05  = RM_p(fix(MC*0.05),:);
RM_p50  = RM_p(fix(MC*0.50),:);
RM_p95  = RM_p(fix(MC*0.95),:);

RMe_   = sort(RMe_);
RMe_05 = RMe_(fix(MC*0.05),:);
RMe_50 = RMe_(fix(MC*0.50),:);
RMe_95 = RMe_(fix(MC*0.95),:);

RMep   = sort(RMep);
RMep05 = RMep(fix(MC*0.05),:);
RMep50 = RMep(fix(MC*0.50),:);
RMep95 = RMep(fix(MC*0.95),:);

close all;

figure('Position',[200 120 1400 600]);
subplot(1,2,1)
   plot(SMrange,RM_p05,'k--'); hold on;
   plot(SMrange,RM_p95,'k--');
   plot(SMrange,RM_p50,'k');
   ylabel('Methow','FontSize',20);
   title('Parameter uncertainty','FontSize',16);
   axis([0 10000 0 12000]);
subplot(1,2,2);
   plot(SMrange,RMe_05,'k--'); hold on;
   plot(SMrange,RMe_95,'k--');
   plot(SMrange,RMe_50,'k');
   plot(SMrange,RMep05,'k--','linewidth',2); 
   plot(SMrange,RMep95,'k--','linewidth',2);
   plot(SMrange,RMep50,'k','linewidth',2);
   title('Parameter uncertainty & environmental variability','FontSize',16);
   axis([0 10000 0 12000]);

% Entiat
SEmax = 10000;
SErange = [1:(SEmax-1)/99:SEmax]';

RE_p = zeros(MC,100);
REe_ = zeros(MC,100);
REep = zeros(MC,100);

alphaE_ml = exp(0.2184);  %alphaE_ml = mean(parmsE(:,1));
betaE_ml  = exp(7.3607);  %betaE_ml  = mean(parmsE(:,2));

for mc = 1:MC;
    clc; if fix(mc/1000)-1000==0; fprintf('Working on %-.0f of %-.0f\n',mc,MC); pause(0.01); end;
    draw = fix(rand*length(parmsE))+1;
    alpha = parmsE(draw,1);
    beta  = parmsE(draw,2);
    sigma = parmsE(draw,3);
    i = 0;
    for S = SErange'; i = i + 1;
        RE_p(mc,i) = alpha*S/(1+S/beta);
        epsilon    = randn(1,1)*sigma;
        REe_(mc,i) = alphaE_ml*S/(1+S/betaE_ml)*exp(epsilon*factor);
        REep(mc,i) = alpha*S/(1+S/beta)*exp(epsilon);
    end;
end;
RE_p   = sort(RE_p);
RE_p05 = RE_p(fix(MC*0.05),:);
RE_p50 = RE_p(fix(MC*0.50),:);
RE_p95 = RE_p(fix(MC*0.95),:);
REe_   = sort(REe_);
REe_05 = REe_(fix(MC*0.05),:);
REe_50 = REe_(fix(MC*0.50),:);
REe_95 = REe_(fix(MC*0.95),:);
REep   = sort(REep);
REep05 = REep(fix(MC*0.05),:);
REep50 = REep(fix(MC*0.50),:);
REep95 = REep(fix(MC*0.95),:);
RE_ml  = alphaE_ml*SErange./(1+SErange/betaE_ml);

figure('Position',[200 120 1400 600]);
subplot(1,2,1)
   plot(SErange,RE_p05,'k--'); hold on;
   plot(SErange,RE_p95,'k--');
   plot(SErange,RE_p50,'k');
   ylabel('Entiat','FontSize',20);
   axis([0 10000 0 10000]);
subplot(1,2,2);
   plot(SErange,REe_05,'k--'); hold on;
   plot(SErange,REe_95,'k--');
   plot(SErange,REe_50,'k');
   plot(SErange,REep05,'k--','linewidth',2); 
   plot(SErange,REep95,'k--','linewidth',2);
   plot(SErange,REep50,'k','linewidth',2);
   axis([0 10000 0 10000]);


% Wenatchee
SWmax = 20000;
SWrange = [1:(SWmax-1)/99:SWmax]';

RW_p = zeros(MC,100);
RWe_ = zeros(MC,100);
RWep = zeros(MC,100);

alphaW_ml = exp(-0.1126);  %alphaW_ml = mean(parmsW(:,1));
betaW_ml  = exp(9.8479);   %betaW_ml  = mean(parmsW(:,2));

for mc = 1:MC;
    clc; if fix(mc/1000)-1000==0; fprintf('Working on %-.0f of %-.0f\n',mc,MC); pause(0.01); end;
    draw = fix(rand*length(parmsW))+1;
    alpha = parmsW(draw,1);
    beta  = parmsW(draw,2);
    sigma = parmsW(draw,3);
    i = 0;
    for S = SWrange'; i = i + 1;
        RW_p(mc,i) = alpha*S/(1+S/beta);
        epsilon    = randn(1,1)*sigma;
        RWe_(mc,i) = alphaW_ml*S/(1+S/betaW_ml)*exp(epsilon*factor);
        RWep(mc,i) = alpha*S/(1+S/beta)*exp(epsilon);
    end;
end;
RW_p   = sort(RW_p);
RW_p05 = RW_p(fix(MC*0.05),:);
RW_p50 = RW_p(fix(MC*0.50),:);
RW_p95 = RW_p(fix(MC*0.95),:);
RWe_   = sort(RWe_);
RWe_05 = RWe_(fix(MC*0.05),:);
RWe_50 = RWe_(fix(MC*0.50),:);
RWe_95 = RWe_(fix(MC*0.95),:);
RWep   = sort(RWep);
RWep05 = RWep(fix(MC*0.05),:);
RWep50 = RWep(fix(MC*0.50),:);
RWep95 = RWep(fix(MC*0.95),:);
RW_ml = alphaW_ml*SWrange./(1+SWrange/betaW_ml);

figure('Position',[200 120 1400 600]);
subplot(1,2,1);
   plot(SWrange,RW_p05,'k--'); hold on;
   plot(SWrange,RW_p95,'k--');
   plot(SWrange,RW_p50,'k');
   axis([0 20000 0 50000]);
   ylabel('Wenatchee','FontSize',20);
subplot(1,2,2);
   plot(SWrange,RWe_05,'k--'); hold on;
   plot(SWrange,RWe_95,'k--');
   plot(SWrange,RWe_50,'k');
   plot(SWrange,RWep05,'k--','linewidth',2); 
   plot(SWrange,RWep95,'k--','linewidth',2);
   plot(SWrange,RWep50,'k','linewidth',2);
   axis([0 20000 0 50000]);

