%==========================================================================
function [C0,Cl,Cbar] = SALMON_concentrations(x);
%==========================================================================

global I drain_order LU omega A mu l W Q0 Ql C00 Cl0 Cbar0 eta mass0 mass q;

C0   = zeros(I,1);
Cl   = zeros(I,1);
Cbar = zeros(I,1);

dx = 100; % Length [m] of a "control volume" for calculating average
          % concentrations
for i = drain_order';
    LUi = LU(i,:)*(1-x(i));%Make x<1 if not all pollution is eliminated
    mass(i)= 2*LUi*omega/(A(i)*mu)*(1-exp(-mu*A(i)/2/l(i)));
    for k = 1:I;
        if W(k,2) == W(i,1);             % If reach k drains into reach i
            C0(i) = C0(i) + Cl(k)*Ql(k); % Adding up pollution mass
        end;
    end;
    C0(i) = C0(i)/Q0(i); % Converting pollution mass to concentration
    if ~isempty(C00);
        if C0(i) > C00(i); 
            fprintf('Warning: C0(%-.0f) > C00(%-.0f)\n',i,i); 
            pause; 
        end;
    end;
    Cx   = C0(i);
    Csum = C0(i);
    for xx = dx:dx:fix(l(i)/dx)*dx;
        Qx        = Q0(i) + q(i)*xx;
        Qx_plus_dx= Qx + q(i)*dx;
        Cx_plus_dx= ((1-eta/2)*Qx*Cx+mass(i)*dx)/((1+eta/2)*Qx_plus_dx);
        Cx        = Cx_plus_dx;
        Csum      = Csum + Cx;
    end;
    Qx         = Qx_plus_dx;
    Qx_plus_dx = Ql(i);
    Cl(i)      = ((1-eta/2)*Qx*Cx+mass(i)*(l(i)-fix(l(i)/dx)*dx))/...
                 ((1+eta/2)*Qx_plus_dx);
    if ~isempty(Cl0);
        if Cl(i) > Cl0(i); 
            fprintf('Warning: Cl(%-.0f) > Cl0(%-.0f)\n',i,i); 
            pause; 
        end;
    end;
    Csum       = Csum + Cl(i);    
    Cbar(i)    = Csum/(l(i)/dx);    
end;