%==========================================================================
% SALMON_pva_graph.m
%==========================================================================

clc;

for m = 1:M;
    
    %Environmental variability only:
    [S,p] = SALMON_forecast(S0(m),alpha(m),beta(m),sigma(m),L(m),returns(m,:),T,QET,MC);
    meanS = mean(S')';
    temp  = sort(S');
    loS   = temp(fix(MC*.05),:);
    upS   = temp(fix(MC*.95),:);

    pause(0.1);
    figure('Position',[40 60 1200 400]);,
    axes('FontName','Palatino Linotype','FontSize',12);
    %subplot(2,1,1); 
    plot([1:100]',meanS(1:100),'Color','Black','LineWidth',1.5); hold on; 
    %plot([1:100]',loS(1:100),'-r','LineWidth',1);
    %plot([1:100]',upS(1:100),'-r','LineWidth',1);
    for mc = 1:min(10,MC);
        plot([1:100]',S(1:100,mc),':k','Color','Black','LineWidth',1.0); 
    end; 
    hold off;
    top = min( S0(m)*15 , 4*max(meanS(1:100)) );
    top = 5000;
    axis([1 100 0 top]);
    xlabel('Years','FontName','Palatino Linotype','FontSize',16);
    ylabel('Spawners','FontName','Palatino Linotype','FontSize',16);
    text(0,top*1.15,SpeciesNames(m,:),'FontName','Palatino Linotype','FontSize',16);
    PrintThis = ['alpha = ',num2str(alpha(m)),'; beta = ',num2str(beta(m))];
    PrintThis = [PrintThis,...
    '; QET = ',num2str(QET),...
    '; std(eps) = ',num2str(std(epsilon(:,m)))];
    if T >= 25; PrintThis = [PrintThis,'; p25 = ',num2str(p(1))];
        if T >= 50; PrintThis = [PrintThis,'; p50 = ',num2str(p(2))];
            if T >= 100; PrintThis = [PrintThis,'; p100 = ',num2str(p(3))];
                if T >= 200; PrintThis = [PrintThis,'; p200 = ',num2str(p(4))]; end;
            end;
        end;
    end;
    text(2,top*1.05,PrintThis,'FontName','Palatino Linotype','FontSize',10);
    text(2,top*1.15,[SpeciesNames(m,:) '- Environmental variability only'],'FontName','Palatino Linotype','FontSize',10);

    % Parameter uncertainty and environmental variability:
    boot1 = xlsread(InputFile,'Methow_boot');
    boot2 = xlsread(InputFile,'Entiat_boot');
    boot3 = xlsread(InputFile,'Wenatchee_boot');

    alpha_bs = [boot1(:,1) boot2(:,1) boot3(:,1)];
    beta_bs  = [boot1(:,2) boot2(:,2) boot3(:,2)];
    sigma_bs = [boot1(:,3) boot2(:,3) boot3(:,3)];

    [rows1,cols1] = size(boot1); cols1 = cols1-3;
    [rows2,cols2] = size(boot2); cols2 = cols2-3;
    [rows3,cols3] = size(boot3); cols3 = cols3-3;

    columns = max([cols1 cols2 cols3]);

    epsilon_bs = zeros(rows1,columns,3);

    epsilon_bs(:,1:cols1,1) = boot1(:,4:end);
    epsilon_bs(:,1:cols2,2) = boot2(:,4:end);
    epsilon_bs(:,1:cols3,3) = boot3(:,4:end);

    [S,p] = SALMON_forecast(S0(m),alpha_bs(:,m),beta_bs(:,m),sigma_bs(:,m),L(m),returns(m,:),T,QET,MC);
    meanS = mean(S')';
    temp  = sort(S');
    loS   = temp(fix(MC*.05),:);
    upS   = temp(fix(MC*.95),:);

    pause(0.1);
    figure('Position',[40 60 1200 400]);
    axes('FontName','Palatino Linotype','FontSize',12);
    plot([1:100]',meanS(1:100),'Color','Black','LineWidth',1.5); hold on; 
    %plot([1:100]',loS(1:100),'-r','LineWidth',1);
    %plot([1:100]',upS(1:100),'-r','LineWidth',1);
    for mc = 1:min(10,MC);
        plot([1:100]',S(1:100,mc),':k','Color','Black','LineWidth',1.0); 
    end; 
    hold off;
    top = min( S0(m)*15 , 4*max(meanS(1:100)) );
    top = 5000;
    axis([1 100 0 top]);
    xlabel('Years','FontName','Palatino Linotype','FontSize',16);
    ylabel('Spawners','FontName','Palatino Linotype','FontSize',16);
    text(0,top*1.15,SpeciesNames(m,:),'FontName','Palatino Linotype','FontSize',16);
    PrintThis = ['alpha = ',num2str(median(alpha_bs(:,m))),'; beta = ',num2str(median(beta_bs(:,m)))];
    PrintThis = [PrintThis,...
    '; QET = ',num2str(QET),...
    '; std(eps) = ',num2str(mean(std(epsilon_bs(:,:,m)')))];
    if T >= 25; PrintThis = [PrintThis,'; p25 = ',num2str(p(1))];
        if T >= 50; PrintThis = [PrintThis,'; p50 = ',num2str(p(2))];
            if T >= 100; PrintThis = [PrintThis,'; p100 = ',num2str(p(3))];
                if T >= 200; PrintThis = [PrintThis,'; p200 = ',num2str(p(4))]; end;
            end;
        end;
    end;
    text(2,top*1.05,PrintThis,'FontName','Palatino Linotype','FontSize',10);
    text(2,top*1.15,[SpeciesNames(m,:) '- Parameter uncertainty and environmental variability'],'FontName','Palatino Linotype','FontSize',10);

end;