%==========================================================================
% SALMON_set_parameters.m
%==========================================================================

%--------------------------------------------------------------------------
% Population parameters
%--------------------------------------------------------------------------
% alpha, beta, and sigma were estimated in GAUSS using data from McClure et
% al. (2003).  S0 and L were taken directly from McClure et al.

SpeciesNames = ['Methow River Spring Chinook   ';...
                'Entiat River Spring Chinook   ';...
                'Wenatchee River Spring Chinook'];
                
%SalmonRawData = xlsread(InputFile,'SalmonRawSpawners');
SalmonRawData = csvread('SalmonRawSpawners.txt'); 

%SalmonWildData = xlsread(InputFile,'SalmonWildSpawners');
SalmonWildData = csvread('SalmonWildSpawners.txt');

% Bootstrap estimates of epsilon
%epsilon1 = xlsread(InputFile,'Methow_boot');
epsilon1 = csvread('Methow_boot.txt');
    epsilon1 = epsilon1(1,4:end)';
%epsilon2 = xlsread(InputFile,'Entiat_boot');
epsilon2 = csvread('Entiat_boot.txt');
    epsilon2 = epsilon2(1,4:end)';
%epsilon3 = xlsread(InputFile,'Wenatchee_boot');
epsilon3 = csvread('Wenatchee_boot.txt');
    epsilon3 = epsilon3(1,4:end)';
[temp1,trash] = size(epsilon1);
[temp2,trash] = size(epsilon2);
[temp3,trash] = size(epsilon3);
epsilon = zeros(max([temp1;temp2;temp3]),3);
epsilon(1:temp1,1) = epsilon1; 
epsilon(1:temp2,2) = epsilon2; 
epsilon(1:temp3,3) = epsilon3;


% Maximum likelihood estimates of alpha, beta, and sigma:

% Beverton-Holt model:

alpha = [1.6506383;...% Methow River Spring Chinook
         1.2440356;...% Entiat River Sprink Chinook
         0.89351089]; % Wenatchee River Spring Chinook
         
beta  = [1777.9655; ...   
         1527.9043; ...
         18918.462];
 
sigma = [0.84623252; ...
         0.78536700; ...
         1.0551452];
 
% Ricker model:
for zz = 1:1; break;
alpha = [1.1959290; ...
         1.1463806; ...
         0.88173202];  
         
beta  = [0.00018236236; ...   
         0.00037096120; ...
         0.000042525502];
 
sigma = [0.86065109; ...
         0.78542640; ...
         1.0549063];
end;
 
 
[M,trash] = size(alpha);

L     = [5; ...
         5; ...
         5];
         
S0    = mean(SalmonRawData(:,2:end))';
     
returns = [0 0 0.111 0.526 0.363;...  % Proportions returning at ages
           0 0 0.074 0.506 0.420;...  % 1 through 5 for each species
           0 0 0.091 0.612 0.297];    % (Referred to as theta in the paper)

gamma = [7.5;5;9]; % Ratio of average stock abundance under pristine watershed conditions relative to current 
                   % conditions (Note: this should be something less than the ratio of average stock 
                   % abundance under pristine watershed and mainstem conditions relative to current conditions.)
                   % According to Mullan (1992), historic spawner abundances in Methow, Entiat, and Wenatchee 
                   % basins were 24000, 3400, and 41000.  Assuming restoring each watershed to pristine 
                   % conditions will bring each stock half way back to their historic abundances gives the 
                   % estimates for gamma that we use here.
gamma = 0.5 * [24000;3400;41000]./S0;

QET = 0.1; % Quasi extinction threshold, as a proportion of the baseline average abundance
                  
T  = 100;  % Number of years for simulations 

MC = 5000; % Number of Monte-Carlo trials to estimate survival probabilities
                  
%------------------------------------------------------------------------------------------------------------
% Watershed parameters
%------------------------------------------------------------------------------------------------------------          
%W = xlsread(InputFile,'WatershedAttributes');
W = csvread('WatershedAttributes.txt');
W = W(2:end,:);

[I,J] = size(W);

x    = zeros(I,1);        % There are 104 watersheds x(i) is 1 if watershed i is protected, 0 otherwise
h    = (      W(:,10)...  % Length of habitat in each reach [m]
       + 0.67*W(:,11)...  % (The .67 and .33 multipliers were added to give
       + 0.33*W(:,12));   % less weight to 'rearing' and 'migration' habitat than to 'spawning' habitat.)
l    = sum(W(:,10:13)')'; % Total length of each reach [m]
LU   = W(:,14:34);        % Vector of human land uses in each watershed[m^2]
A    = W(:,6);            % Area of each watershed [m^2]
cost = W(:,35);           % NOAA estimated cost of critical habitat designations in each watershed [$]

%Turn on the following line to increase the cost variation:
%cost = cost.^3 * mean(cost)/mean(cost.^3);

%Turn on the following line to simulate equal area watersheds
%A   = ones(size(A))*mean(A); W(:,6) = ones(size(W(:,6)))*mean(W(:,6));


%------------------------------------------------------------------------------------------------------------
% Calculate length of all downstream reaches:
%------------------------------------------------------------------------------------------------------------
ldown = zeros(I,1);
for i = 1:I; 
    done = 0;
    wshed = i;
    reach = W(i,1);
    while done == 0;
        toreach = W(wshed,2);
        towshed = find(W(:,1)==toreach);
        if isempty(towshed); 
            done = 1;  
        else
            ldown(i) = ldown(i) + sum(W(towshed,10:13));
            wshed = towshed;
            reach = toreach;
        end; 
    end;
end;
ldown = ldown + (sum(W(:,10:13)'))'/2;


%------------------------------------------------------------------------------------------------------------
% Calculate flow rates
%------------------------------------------------------------------------------------------------------------
Q0  = W(:,4);            % Beginning flow rate [m^3/yr]
Ql  = W(:,5);            % Ending flow rate

for zz = 1:1; %break;
    
    % Calculate the beginning and ending flow rates for each reach:
    %NOTE: HUCs must be sorted in the proper drain order for this to work!
    
    Q0 = Q0*0;
    Ql = Ql*0;
    
    QfinalM = 1408270047; % [m^3/yr]
    QfinalE =  549195046; % [m^3/yr]
    QfinalW = 3065205162; % [m^3/yr]

    q  = zeros(I,1);

    HUC   = W(:,1);
    toHUC = W(:,2);
    l     = (sum(W(:,10:13)'))'; % Total length of each reach;

    startersM = 0;
    for i = (find(W(:,7)==1))';
        if isempty(find(W(:,2)==W(i,1))); startersM = startersM + 1; end;
    end;
    q(find(W(:,7)==1)) = (QfinalM - 5*startersM)/sum(l(find(W(:,7)==1)));
    du(find(W(:,7)==1)) = l(find(W(:,7)==1))/2;
    %q(find(W(:,7)==1)) = 0;
    for i = (find(W(:,7)==1))';
        if isempty(find(W(:,2)==W(i,1))); 
            Q0(i) = 4465000.4; % [m^3/yr] 
            Ql(i) = Q0(i) + q(i)*l(i);
        else fromHUCindex = find(W(:,2)==W(i,1));
            Q0(i) = sum(Ql(fromHUCindex));
            Ql(i) = Q0(i) + q(i)*l(i);
        end;
    end;

    startersE = 0;
    for i = (find(W(:,8)==1))';
        if isempty(find(W(:,2)==W(i,1))); startersE = startersE + 1; end;
    end;
    q(find(W(:,8)==1)) = (QfinalE - 5*startersE)/sum(l(find(W(:,8)==1))); 
    %q(find(W(:,8)==1)) = 0;
    for i = (find(W(:,8)==1))';
        if isempty(find(W(:,2)==W(i,1))); 
            Q0(i) = 4465000.4; % [m^3/yr] 
            Ql(i) = Q0(i) + q(i)*l(i);
        else fromHUCindex = find(W(:,2)==W(i,1));
            Q0(i) = sum(Ql(fromHUCindex));
            Ql(i) = Q0(i) + q(i)*l(i);
        end;
    end;

    startersW = 0;
    for i = (find(W(:,9)==1))';
        if isempty(find(W(:,2)==W(i,1))); startersW = startersW + 1; end;
    end;
    q(find(W(:,9)==1)) = (QfinalW - 5*startersW)/sum(l(find(W(:,9)==1))); 
    %q(find(W(:,9)==1)) = 0;
    for i = (find(W(:,9)==1))';
        if isempty(find(W(:,2)==W(i,1))); 
            Q0(i) = 4465000.4; % [m^3/yr] 
            Ql(i) = Q0(i) + q(i)*l(i);
        else fromHUCindex = find(W(:,2)==W(i,1));
            Q0(i) = sum(Ql(fromHUCindex));
            Ql(i) = Q0(i) + q(i)*l(i);
        end;
    end;
    
end; 

%Turn on the following line to make flows uniform throughout the network
%Q0 = ones(size(Q0))*mean([Q0;Ql]); Ql = Q0;


%------------------------------------------------------------------------------------------------------------
% Calculate "pollution" concentrations along each river reach:
%------------------------------------------------------------------------------------------------------------
% This comes from Pess et al. (2003), who estimated the following eqation for fish/km:
% spawner density [fish/km] = exp(alpha+b1*%tilled+b2*%bedrock+b3*ln(%ag)+b4*ln(%urban))
% We can relate this equation to our pollutant "concentration," Cbari, in our "habitat capacity" function.
omega = ones(21,1); % Mass of pollutants from each human land use 
                    % activity all provisionally normalized to one.
for zz = 1:1; %break;
% This assumes the 1992 NLCD classification system:
omega = [  0;... Land use code 11: Open water
           0;... Land use code 12: Perennial ice/snow
       0.130;... Land use code 21: Low intensity residential
       0.130;... Land use code 22: High intensity residential
       0.130;... Land use code 23: Commercial/industrial/transportation
           0;... Land use code 31: Bare rock/sand/clay
           0;... Land use code 32: Quarries/strip mines/gravel pits
           0;... Land use code 33: Transitional
     0.00336;... Land use code 41: Deciduous forest
     0.00336;... Land use code 42: Evergreen forest
     0.00336;... Land use code 43: Mixed forest
           0;... Land use code 51: Shrubland
       0.320;... Land use code 61: Orchards/vineyards/other
           0;... Land use code 71: Grasslands/herbaceous
       0.320;... Land use code 81: Pasture/hay
       0.320;... Land use code 82: Row crops
       0.320;... Land use code 83: Small grains
       0.320;... Land use code 84: Fallow
       0.130;... Land use code 85: Urban/recreational grasses
           0;... Land use code 91: Woody wetlands
           0];  %Land use code 92: Emergent harvaceous wetlands
       
%omega = zeros(size(omega));
           
end;
      
omega = omega*100000; 

Dhs   = 1000;    % Distance [m] after which pollutant concentration
                 % has decreased by 1/2 during flow in (un-mapped)
                 % streams
mu    = -log(0.5)/Dhs;
mass  = zeros(I,1);   % Loading rate per unit distance of river length [g/m]
Dhr   = 10000;        % Distance [m] after which pollutant concentration 
                      % has decreased by 1/2 in rivers
eta   = -log(0.5)/Dhr;% Pollutant decay rate in rivers

C0    = zeros(I,1);   % Beginning concentration 
Cl    = zeros(I,1);   % Ending concentration
Cbar  = zeros(I,1);   % Average concentration
[trash,drain_order] = sort(W(:,3));

x = zeros(I,1);
C00 = []; Cl0 = []; Cbar0 = [];
[C0,Cl,Cbar] = SALMON_concentrations(x);
C00   = C0;
Cl0   = Cl;
Cbar0 = Cbar;


%------------------------------------------------------------------------------------------------------------
% Calculate b and calibrate rho for each stock
%------------------------------------------------------------------------------------------------------------
answer = input('\nRe-calibrate model? [0] = no; [1] = yes ');
if answer == 1;
    
rho = [0.0067982;...
       0.0141800;...
       0.0252980]; % Initial guess for rho(mm) 

for m = 1:M; % m indexes the stocks
    wsheds = find(W(:,m+6)==1);
    b(m) = gamma(m)*beta(m)/sum(h(wsheds));
    inc = 0.01;
    done = 0;
    while done == 0;
        beta_hat = b(m)*sum(h(wsheds).*exp(-rho(m)*Cbar(wsheds)));
        fract_diff = (beta_hat - beta(m))/beta(m);
        SALMON_header;
        fprintf('Calibrating rho(%-.0f): rho      = %10.8f\n',m,rho(m));
        fprintf('                    beta(%-.0f)  = %10.1f\n',m,beta(m));
        fprintf('                    beta_hat = %10.1f\n',beta_hat); pause(0.1);
        if abs(fract_diff) < 0.001; done = 1;
        elseif fract_diff > 0;
            rho(m) = rho(m) * (1 + inc);
        elseif fract_diff < 0;
            rho(m) = rho(m) * (1 - inc);
        end;
    end; 
end;

end;